import 'package:example_app/example_ads.dart';
import 'package:example_app/google/google_banner_ads.dart';
import 'package:example_app/second_page.dart';
import 'package:flutter/material.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:th_studio_common_module/admod/interstitial_admod.dart';
import 'package:th_studio_common_module/admod/native_admod.dart';
import 'package:th_studio_common_module/admod/reward_admod.dart';

class GoogleAdPage extends StatelessWidget {
  static PageRoute buildPageRoute() {
    return PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => GoogleAdPage(),
      transitionsBuilder: (context, animation, secondaryAnimation, child) {
        return child;
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return GoogleAdPageContent();
  }
}

class GoogleAdPageContent extends StatefulWidget {
  GoogleAdPageContent({Key key}) : super(key: key);

  @override
  _GoogleAdPageContentState createState() => _GoogleAdPageContentState();
}

class _GoogleAdPageContentState extends State<GoogleAdPageContent> {
  InterstitialAdMod interstitialAdMod = InterstitialAdMod();
  RewardAdMod rewardAd = RewardAdMod();

  @override
  void initState() {
    super.initState();
    interstitialAdMod.loadAd(INTERSTITIAL1);
    rewardAd.loadAd(REWARDED1);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Google SDK'),
      ),
      body: ListView(
        children: [
          _createButton('Interstitial ads', () => onClickInterstitial()),
          _createButton('Reward ads', () => onClickRewardAd()),
          _createButton(
              'Google Banner show case', () => onGoogleBannerListClick()),
          NativeAdMod().createNativeWidget(NATIVE1, 300, 300),
        ],
      ),
    );
  }

  Widget _createButton(String title, VoidCallback onClick) {
    return Padding(
        padding: const EdgeInsets.only(top: 8.0, left: 8.0, right: 8.0),
        child: SizedBox(
            width: double.infinity,
            child: ElevatedButton(onPressed: onClick, child: Text(title))));
  }

  onClickInterstitial() {
    interstitialAdMod.show(
        listener: AdListener(
            onAdClosed: (ad) => navigateToOtherScreen(),
            onAdFailedToLoad: (ad, error) => navigateToOtherScreen()));
  }

  void navigateToOtherScreen() async {
    Navigator.push(context, SecondPage.buildPageRoute());
  }

  onClickRewardAd() {
    rewardAd.show(
        listener: AdListener(
            onAdClosed: (ad) => navigateToOtherScreen(),
            onAdFailedToLoad: (ad, error) => navigateToOtherScreen()));
  }

  onGoogleBannerListClick() {
    Navigator.push(context, GoogleBannerShowCasePage.buildPageRoute());
  }
}
