import 'package:google_mobile_ads/google_mobile_ads.dart';

/// Full-screen ads that cover the interface of an app until closed by the
/// user.
/// They're best used at natural pauses in the flow of an app's execution,
/// such as in between levels of a game or just after completing a task.
class InterstitialAdMod {
  InterstitialAd _ad;
  AdListener additionalListener;
  AdListener _listener;

  InterstitialAdMod() {
    _listener = AdListener(
      // Called when an ad is successfully received.
      onAdLoaded: (Ad ad) {
        if (additionalListener != null) additionalListener.onAdLoaded(ad);
      },
      // Called when an ad request failed.
      onAdFailedToLoad: (Ad ad, LoadAdError error) {
        if (additionalListener != null)
          additionalListener.onAdFailedToLoad(ad, error);
        if (error.code != 2) _reload();
      },
      // Called when an ad opens an overlay that covers the screen.
      onAdOpened: (Ad ad) {
        if (additionalListener != null) additionalListener.onAdOpened(ad);
        _reload();
      },
      // Called when an ad removes an overlay that covers the screen.
      onAdClosed: (Ad ad) {
        if (additionalListener != null) additionalListener.onAdClosed(ad);
        _reload();
      },
      // Called when an ad is in the process of leaving the application.
      onApplicationExit: (Ad ad) {
        if (additionalListener != null)
          additionalListener.onApplicationExit(ad);
      },
    );
  }

  void _reload() {
    _ad.dispose();
    _ad.load();
  }

  InterstitialAd _createInterstitialAdMod(String bannerId,
      {AdRequest request = const AdRequest(),
      AdListener listener = const AdListener()}) {
    return InterstitialAd(
        adUnitId: bannerId, listener: listener, request: request);
  }

  void loadAd(String bannerId) {
    _ad = _createInterstitialAdMod(bannerId,
        request: AdRequest(), listener: _listener);
    _ad.load();
  }

  void show({AdListener listener}) async {
    this.additionalListener = listener;
    if (await _ad.isLoaded()) {
      _ad.show();
    } else {
      if (listener != null) listener.onAdFailedToLoad(_ad, null);
    }
  }
}
