import 'package:google_mobile_ads/google_mobile_ads.dart';

class RewardAdMod {
  RewardedAd _rewardedAd;
  bool _rewardedReady = false;

  AdListener _listener;
  AdListener _additionalListener;
  String _adId;

  RewardAdMod() {
    _listener = AdListener(onAdLoaded: (Ad ad) {
      print('${ad.runtimeType} loaded.');
      _rewardedReady = true;
      if (_additionalListener != null) _additionalListener.onAdLoaded(ad);
    }, onAdFailedToLoad: (Ad ad, LoadAdError error) {
      print('${ad.runtimeType} failed to load: $error');
      ad.dispose();
      if (error.code != 2) _reloadAd();
      if (_additionalListener != null)
        _additionalListener.onAdFailedToLoad(ad, error);
    }, onAdOpened: (Ad ad) {
      print('${ad.runtimeType} onAdOpened.');
      if (_additionalListener != null) {
        _additionalListener.onAdOpened(ad);
      }
      ad.dispose();
      _reloadAd();
    }, onAdClosed: (Ad ad) {
      print('${ad.runtimeType} closed.');
      ad.dispose();
      _reloadAd();
      if (_additionalListener != null) {
        _additionalListener.onAdClosed(ad);
      }
    }, onApplicationExit: (Ad ad) {
      if (_additionalListener != null) {
        _additionalListener.onApplicationExit(ad);
      }
    }, onRewardedAdUserEarnedReward: (RewardedAd ad, RewardItem reward) {
      if (_additionalListener != null) {
        _additionalListener.onRewardedAdUserEarnedReward(ad, reward);
      }
      print('onRewardedAdUserEarnedReward $reward');
    });
  }

  void _reloadAd() {
    if (_adId != null) {
      _rewardedAd = null;
      loadAd(_adId);
    }
  }

  void loadAd(String id) {
    _adId = id;
    _rewardedAd ??=
        RewardedAd(adUnitId: id, request: AdRequest(), listener: _listener)
          ..load();
  }

  void show({AdListener listener}) {
    this._additionalListener = listener;
    if (_rewardedReady) {
      _rewardedAd.show();
      _rewardedAd = null;
      _rewardedReady = false;
    } else {
      listener.onAdClosed(_rewardedAd);
    }
  }
}
